@@ -1,5 +1,5 @@
 # Copyright (C) 2009 Nokia Corporation
-# Copyright (C) 2009-2012 Collabora Ltd.
+# Copyright (C) 2009 Collabora Ltd.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -61,21 +61,16 @@ CONN_IFACE_ALIASING = CONN + '.Interface.Aliasing'
 CONN_IFACE_AVATARS = CONN + '.Interface.Avatars'
 CONN_IFACE_CAPS = CONN + '.Interface.Capabilities'
 CONN_IFACE_CONTACTS = CONN + '.Interface.Contacts'
+CONN_IFACE_CONTACT_CAPS_DRAFT1 = CONN + '.Interface.ContactCapabilities.DRAFT'
 CONN_IFACE_CONTACT_CAPS = CONN + '.Interface.ContactCapabilities'
 CONN_IFACE_REQUESTS = CONN + '.Interface.Requests'
 CONN_IFACE_SIMPLE_PRESENCE = CONN + '.Interface.SimplePresence'
 CONN_IFACE_POWER_SAVING = CONN + '.Interface.PowerSaving'
-CONN_IFACE_SERVICE_POINT = CONN + '.Interface.ServicePoint'
 
 CONN_STATUS_CONNECTED = 0
 CONN_STATUS_CONNECTING = 1
 CONN_STATUS_DISCONNECTED = 2
 
-ATTR_CONTACT_ID = CONN + '/contact-id'
-ATTR_ALIAS = CONN_IFACE_ALIASING + '/alias'
-ATTR_AVATAR_TOKEN = CONN_IFACE_AVATARS + '/token'
-ATTR_PRESENCE = CONN_IFACE_SIMPLE_PRESENCE + '/presence'
-
 CONN_STATUS_REASON_NONE = 0
 CONN_STATUS_REASON_REQUESTED = 1
 CONN_STATUS_REASON_NETWORK_ERROR = 2
@@ -166,10 +161,6 @@ MEDIA_STREAM_DIRECTION_SEND = 1
 MEDIA_STREAM_DIRECTION_RECEIVE = 2
 MEDIA_STREAM_DIRECTION_BIDIRECTIONAL = 3
 
-SERVICE_POINT_TYPE_NONE = 0
-SERVICE_POINT_TYPE_EMERGENCY = 1
-SERVICE_POINT_TYPE_COUNSELING = 2
-
 CLIENT = tp_name_prefix + '.Client'
 CLIENT_PATH = tp_path_prefix + '/Client'
 OBSERVER = tp_name_prefix + '.Client.Observer'
@@ -181,11 +172,13 @@ ACCOUNT = tp_name_prefix + '.Account'
 ACCOUNT_IFACE_AVATAR = ACCOUNT + '.Interface.Avatar'
 ACCOUNT_IFACE_ADDRESSING = ACCOUNT + '.Interface.Addressing'
 ACCOUNT_IFACE_HIDDEN = ACCOUNT + '.Interface.Hidden.DRAFT1'
+ACCOUNT_IFACE_NOKIA_COMPAT = 'com.nokia.Account.Interface.Compat'
+ACCOUNT_IFACE_NOKIA_REQUESTS = 'com.nokia.Account.Interface.ChannelRequests'
 ACCOUNT_IFACE_NOKIA_CONDITIONS = 'com.nokia.Account.Interface.Conditions'
-ACCOUNT_PATH_PREFIX = tp_path_prefix + '/Account/'
 
 AM = tp_name_prefix + '.AccountManager'
 AM_IFACE_HIDDEN = AM + '.Interface.Hidden.DRAFT1'
+AM_IFACE_NOKIA_QUERY = 'com.nokia.AccountManager.Interface.Query'
 AM_PATH = tp_path_prefix + '/AccountManager'
 
 CR = tp_name_prefix + '.ChannelRequest'
@@ -198,19 +191,3 @@ CD_REDISPATCH = CD + '.Interface.Redispatch.DRAFT'
 
 MC = tp_name_prefix + '.MissionControl5'
 MC_PATH = tp_path_prefix + '/MissionControl5'
-
-TESTDOT = "org.freedesktop.Telepathy.MC.Test."
-TESTSLASH = "/org/freedesktop/Telepathy/MC/Test/"
-
-TEST_DBUS_ACCOUNT_SERVICE = TESTDOT + "DBusAccountService"
-TEST_DBUS_ACCOUNT_SERVICE_PATH = TESTSLASH + "DBusAccountService"
-TEST_DBUS_ACCOUNT_SERVICE_IFACE = TEST_DBUS_ACCOUNT_SERVICE
-
-TEST_DBUS_ACCOUNT_PLUGIN_PATH = TESTSLASH + "DBusAccountPlugin"
-TEST_DBUS_ACCOUNT_PLUGIN_IFACE = TESTDOT + "DBusAccountPlugin"
-
-PARAM_FLAG_REQUIRED = 1
-PARAM_FLAG_REGISTER = 2
-PARAM_FLAG_HAS_DEFAULT = 4
-PARAM_FLAG_SECRET = 8
-PARAM_FLAG_DBUS_PROPERTY = 16
